@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>MainWindow</name>
     <message>
@@ -900,4 +898,4 @@ Zárja be a programot vagy várja meg amíg befejezi a műveletet, majd próbál
         <translation>Ezt a programot adminisztrátorként kell futtatnia.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
