@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pt">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
 <context>
     <name>MainWindow</name>
     <message>
@@ -900,4 +898,4 @@ Fechar esse programa ou esperar que ele termine e tentar novamente.</translation
         <translation>Este programa tem de ser executado como administrador.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
